@@ -59,7 +59,8 @@ ggdag_collider <- function(.tdy_dag, ..., edge_type = "link_arc", node_size = 16
 
   p <- if_not_tidy_daggity(.tdy_dag, ...) %>%
     node_collider() %>%
-    ggplot2::ggplot(ggplot2::aes(x = x, y = y, xend = xend, yend = yend, color = forcats::fct_rev(colliders))) +
+    dplyr::mutate(colliders = forcats::fct_rev(colliders)) %>%
+    ggplot2::ggplot(ggplot2::aes(x = x, y = y, xend = xend, yend = yend, color = colliders)) +
     edge_function() +
     scale_adjusted()
 
